@@ -22,7 +22,8 @@ target("lua")
     -- add definitions
     add_defines("LUA_COMPAT_5_1", "LUA_COMPAT_5_2", "LUA_COMPAT_5_3", {public = true})
     if is_plat("windows") then
-        add_defines("LUA_USE_WINDOWS")
+        -- it has been defined in luaconf.h
+        --add_defines("LUA_USE_WINDOWS")
     elseif is_plat("macosx", "iphoneos") then
         add_defines("LUA_USE_MACOSX")
     else
